# Tutorials website

## Requirements

```
numpydoc
sphinx
sphinx_gallery
```

## Build commands

```bash
make clean           # Remove all files generated by the website build
make html            # Build the website, running all the examples (slow)
make html-noplot     # Build the website, without running all the examples (fast)
make notebooks       # Update the notebooks directory, *after* building the website
make merge-notebooks # Merge notebooks for Colab, *after* making the notebooks

firefox _build/html/index.html  # Open the built website
```

## Typical full build (slow)

```bash
make html
firefox _build/html/index.html
```

## Update notebooks (fast)

```bash
make html-noplot
make notebooks
make merge-notebooks
```

## Push the website

```bash
make push-pages
```
